==> haskell-yaml-0.10.1.1-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yaml
version: 0.10.1.1
id: yaml-0.10.1.1-6yEhnvvT8X92KHGOVP80PX
key: yaml-0.10.1.1-6yEhnvvT8X92KHGOVP80PX
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
stability: stable
homepage: https://github.com/snoyberg/yaml#readme
synopsis: Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>
category: Data
abi: 9e2767e1bb725b59ee794041072565ee
exposed: True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH Text.Libyaml
hidden-modules: Paths_yaml
import-dirs: /usr/lib/ghc-8.4.3/site-local/yaml-0.10.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/yaml-0.10.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/yaml-0.10.1.1
hs-libraries: HSyaml-0.10.1.1-6yEhnvvT8X92KHGOVP80PX
extra-libraries:
    yaml
depends:
    aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL
    attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE base-4.11.1.0
    bytestring-0.10.8.2 conduit-1.3.0.3-2kQyPNl7LmHLxxI2wSVWau
    containers-0.5.11.0 directory-1.3.1.5 filepath-1.4.2 mtl-2.2.2
    resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl template-haskell-2.13.0.0
    text-1.2.3.0 transformers-0.5.5.0
    unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL=912860ab3519756596367ddae154025c
             attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             conduit-1.3.0.3-2kQyPNl7LmHLxxI2wSVWau=165b50aef4a213b491f6528fa1a2f4d1
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q=b5273090c64c1efd0c4504885cc2bdef
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa=81e1d2b217f05c2ba43642acf6d96f3b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html: /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yaml-0.10.2.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yaml
version: 0.10.2.0
id: yaml-0.10.2.0-Cnn4vyBZsl57De3iS0x7x
key: yaml-0.10.2.0-Cnn4vyBZsl57De3iS0x7x
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
stability: stable
homepage: https://github.com/snoyberg/yaml#readme
synopsis: Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>
category: Data
abi: 885139f16ec1ec7e9d6afbfd22b62ef3
exposed: True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH Text.Libyaml
hidden-modules: Paths_yaml
import-dirs: /usr/lib/ghc-8.4.3/site-local/yaml-0.10.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/yaml-0.10.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/yaml-0.10.2.0
hs-libraries: HSyaml-0.10.2.0-Cnn4vyBZsl57De3iS0x7x
extra-libraries:
    yaml
depends:
    aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL
    attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE base-4.11.1.0
    bytestring-0.10.8.2 conduit-1.3.0.3-7hM2y3vt6zPJrBL0QWA5kl
    containers-0.5.11.0 directory-1.3.1.5 filepath-1.4.2 mtl-2.2.2
    resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl template-haskell-2.13.0.0
    text-1.2.3.0 transformers-0.5.5.0
    unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL=912860ab3519756596367ddae154025c
             attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             conduit-1.3.0.3-7hM2y3vt6zPJrBL0QWA5kl=027922e93a267b72b868d4ff5db4d6d0
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q=b5273090c64c1efd0c4504885cc2bdef
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa=81e1d2b217f05c2ba43642acf6d96f3b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html: /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
